SystemOrganization addCategory: 'Orbeon_Persistence_API'!

WARestfulHandler subclass: #WAOrbeonPersistenceApiService
	instanceVariableNames: ''
	classVariableNames: ''
	poolDictionaries: ''
	category: 'Orbeon_Persistence_API'!

!WAOrbeonPersistenceApiService methodsFor: 'summary' stamp: 'BrunoBB 08/17/2015 15:33'!
applyQueryToFormDefinition: xmlDocument
	| queryNodes queryFields result |

	queryFields  := Dictionary new.
	result := Orbeon_Form_Data getAllFormDefinitions select: [:each | each deleted = 'N'].

	queryNodes := (xmlDocument allElementsNamed: 'query') do: [:node | 
		node strings notEmpty ifTrue: [queryFields at: (node attributeAt: 'name') put: node strings last]].

	queryFields keysAndValuesDo: [:key :value |
		(key = 'application-name') ifTrue: [result := result select: [:each | each app = (queryFields at: 'application-name')]].
		(key = 'form-name') ifTrue: [result := result select: [:each | each form = (queryFields at: 'form-name')]].
		(key = 'title') ifTrue: [result := result select: [:each | each title = (queryFields at: 'title')]].
		(key = 'description') ifTrue: [result := result select: [:each | each description = (queryFields at: 'description')]].
	].

	^result! !

!WAOrbeonPersistenceApiService methodsFor: 'summary' stamp: 'BrunoBB 08/17/2015 14:55'!
applyQueryToFormInstance: instances queryNodes: collectionOfOrbeonQueryNode
	|  query |

	query := collectionOfOrbeonQueryNode select: [:each | each isSearchAndHasValue].

	^(instances select: [:each | each satisfyQuery: query]) asOrderedCollection! !

!WAOrbeonPersistenceApiService methodsFor: 'service-delete' stamp: 'BrunoBB 08/21/2015 11:07'!
deleteFormDefinitionWithId: id
	"This method is called by Orbeon when a user click 'Send' in a Form Instance page"
	| orbeonInstance |
	<delete>
	<path: '/crud/orbeon/builder/data/{1}/data.xml'>

	Orbeon_Form_Data logicalRemoveFormDefinitionWithId: id ifAbsent: []! !

!WAOrbeonPersistenceApiService methodsFor: 'service-delete' stamp: 'BrunoBB 08/21/2015 11:07'!
deleteFormDraft: formName app: app withId: id
	"This method is called by Orbeon when a user click 'Send' in a Form Instance page"
	| orbeonInstance |
	<delete>
	<path: '/crud/{2}/{1}/draft/{3}/data.xml'>

	Orbeon_Form_Data removeFormDraftWithId: id form: formName app: app ifAbsent: []! !

!WAOrbeonPersistenceApiService methodsFor: 'service-delete' stamp: 'BrunoBB 08/21/2015 11:09'!
deleteFormInstance: formName app: app withId: id
	"This method is called by Orbeon when a user click -Send- in a Form Instance page"
	| orbeonInstance |
	<delete>
	<path: '/crud/{2}/{1}/data/{3}/data.xml'>

	Orbeon_Form_Data logicalRemoveFormInstanceWithId: id ifAbsent: []! !

!WAOrbeonPersistenceApiService methodsFor: 'service-put' stamp: 'BrunoBB 08/10/2015 13:17'!
duplicateFormDefinitionNewId: id
	"This method is called by Orbeon when a user click 'Send' in a Form Instance page"
	| orbeonInstance |
	<put>
	<produces: 'application/xml'>
	<path: '/crud/orbeon/builder/data/{1}/data.xml'>

	orbeonInstance := Orbeon_Form_Data new.

	orbeonInstance xml: self requestContext request rawBody;
		isDefinition: true;
		document_id: id;
		setMetadata;
		form_version: (self requestContext request headerAt: 'orbeon-form-definition-version');
		updateLastModifiedTime;
		addToStorage.! !

!WAOrbeonPersistenceApiService methodsFor: 'service-put' stamp: 'BrunoBB 08/10/2015 14:02'!
duplicateFormInstance: formName app: app newId: id
	"This method is called by Orbeon when a user click 'Send' in a Form Instance page"
	| orbeonInstance |
	<put>
	<produces: 'application/xml'>
	<path: '/crud/{2}/{1}/data/{3}/data.xml'>

	orbeonInstance := Orbeon_Form_Data new.

	orbeonInstance xml: self requestContext request rawBody;
		app: app;
		form: formName;
		document_id: id;
		form_version: (self requestContext request headerAt: 'orbeon-form-definition-version');
		updateLastModifiedTime;
		addToStorage.! !

!WAOrbeonPersistenceApiService methodsFor: 'summary' stamp: 'BrunoBB 08/17/2015 15:03'!
generateXmlAnswerFor: formDefinition summary: instanceCollection withQueryNodes: collectionOfOrbeonQueryNode user: username group: group searchTotal: searchTotal
	| xmlWriter summaryFields |

	xmlWriter := XMLWriter new.
	summaryFields := collectionOfOrbeonQueryNode select: [:each | each isSummary] thenCollect: [:each | each name].

	xmlWriter writeWith: [:writer | | tag |
		tag := writer tag: 'documents' attributes: (self getArrayOfOrbeonHeadersFor: instanceCollection searchTotal: searchTotal).
		tag with: [instanceCollection do: [:each | self generateXmlNodeFor: each definition: formDefinition summary: summaryFields with: writer user: username group: group]].
	].

	 ^xmlWriter contents! !

!WAOrbeonPersistenceApiService methodsFor: 'summary' stamp: 'BrunoBB 08/17/2015 15:36'!
generateXmlAnswerForBuilderSummary: definitionCollection searchTotal: searchTotal
	| xmlWriter |

	xmlWriter := XMLWriter new.

	xmlWriter writeWith: [:writer | | tag |
		tag := writer tag: 'documents' attributes: (self getArrayOfOrbeonHeadersFor: definitionCollection searchTotal: searchTotal).
		tag with: [definitionCollection do: [:each | self generateXmlNodeForDefinition: each with: writer]].
	].

	 ^xmlWriter contents! !

!WAOrbeonPersistenceApiService methodsFor: 'summary' stamp: 'BrunoBB 08/16/2015 16:50'!
generateXmlNodeFor: anOrbeon_Form_Data definition: formDefinition summary: collectionOfNames with: aXMLWriter user: username group: group
	| nodeAttributes tag |

	nodeAttributes := OrderedCollection new
		add: 'created' -> anOrbeon_Form_Data created asOrbeonDateTimeString;
		add: 'draft' -> anOrbeon_Form_Data printDraft;
		add: 'last-modified' -> anOrbeon_Form_Data last_modified_time asOrbeonDateTimeString;
		add: 'name' -> anOrbeon_Form_Data document_id;
		add: 'operations' -> (self getPermissionsFor: anOrbeon_Form_Data user: username group: group in: formDefinition);
		asArray.

	tag := aXMLWriter tag: 'document' attributes: nodeAttributes.

	tag with: [aXMLWriter 
						tag: 'details' 
						with: [(anOrbeon_Form_Data getValueOfFields: collectionOfNames) 
									do: [:each | aXMLWriter tag: 'detail' with: each]]].! !

!WAOrbeonPersistenceApiService methodsFor: 'summary' stamp: 'BrunoBB 08/15/2015 15:58'!
generateXmlNodeForDefinition: anOrbeon_Form_Data with: aXMLWriter
	| nodeAttributes tag |

	nodeAttributes := OrderedCollection new
		add: 'created' -> anOrbeon_Form_Data created asOrbeonDateTimeString;
		add: 'draft' -> anOrbeon_Form_Data printDraft;
		add: 'last-modified' -> anOrbeon_Form_Data last_modified_time asOrbeonDateTimeString;
		add: 'name' -> anOrbeon_Form_Data document_id;
		add: 'operations' -> '*';
		asArray.

	tag := aXMLWriter tag: 'document' attributes: nodeAttributes.

	tag with: [aXMLWriter tag: 'details' 
									with: [aXMLWriter tag: 'detail' with: anOrbeon_Form_Data app.
											aXMLWriter tag: 'detail' with: anOrbeon_Form_Data form.
											aXMLWriter tag: 'detail' with: anOrbeon_Form_Data title.
											aXMLWriter tag: 'detail' with: anOrbeon_Form_Data description.]]! !

!WAOrbeonPersistenceApiService methodsFor: 'summary' stamp: 'BrunoBB 08/17/2015 15:03'!
getArrayOfOrbeonHeadersFor: anOrderedCollection searchTotal: searchTotal

	^OrderedCollection new
		add: 'xmlns:ev' -> 'http://www.w3.org/2001/xml-events';
		add: 'xmlns:f' -> 'http//www.orbeon.com/function';
		add: 'xmlns:frf' -> 'java:org.orbeon.oxf.fr.FormRunner';
		add: 'xmlns:odt' -> 'http://orbeon.org/oxf/xml/datatypes';
		add: 'xmlns:oxf' -> 'http://www.orbeon.com/oxf/processors';
		add: 'xmlns:p' -> 'http://www.orbeon.com/oxf/pipeline';
		add: 'xmlns:saxon' -> 'http://saxon.sf.net/';
		add: 'xmlns:sql' -> 'http://orbeon.org/oxf/xml/sql';
		add: 'xmlns:xf' -> 'http://www.w3.org/2002/xforms';
		add: 'xmlns:xi' -> 'http://www.w3.org/2001/XInclude';
		add: 'xmlns:xpl' -> 'java:org.orbeon.oxf.pipeline.api.FunctionLibrary';
		add: 'xmlns:xs' -> 'http://www.w3.org/2001/XMLSchema';
		add: 'xmlns:xxf' -> 'http://orbeon.org/oxf/xml/xforms';
		add: 'page-size' -> '10';
		add: 'total' -> Orbeon_Form_Data totalSize printString;
		add: 'search-total' -> searchTotal printString;
		asArray! !

!WAOrbeonPersistenceApiService methodsFor: 'service-get' stamp: 'BrunoBB 08/24/2015 10:53'!
getDefinitionForFormInstanceWithId: id form: form app: app
	"This service is called when a click is performed on the Orbeon Form Summary page (or go directly to edit/view page of a form). The Summary then open the Form Instance in it's corresponding form definition.
	This service is used in combination of #getXmlOfFormInstanceWithId:form:app: to <get> the actual data of the form"
	| orbeonDefinition latestVersionNumber |
	<get>
	<produces: 'application/xml'>
	<path: '/crud/{3}/{2}/form/form.xhtml?document={1}'>

	orbeonDefinition := Orbeon_Form_Definition getLatestFormDefinition: form app: app.
	latestVersionNumber := Orbeon_Form_Definition getLatestFormDefinitionVersion: form app: app.

	self requestContext response headerAt: 'orbeon-form-definition-version' put: latestVersionNumber printString.

	^((GRCodec forEncoding: 'utf-8') decode: orbeonDefinition xml) asString! !

!WAOrbeonPersistenceApiService methodsFor: 'service-get' stamp: 'BrunoBB 08/17/2015 13:47'!
getFormDefinitionWithId: id 
	"This service is called when a click is performed on the Orbeon Form Builder Summary page.
	The Summary then should open the Orbeon Builder with the code of the clicked form."
	| orbeonData |
	<get>
	<produces: 'application/xml'>
	<path: '/crud/orbeon/builder/data/{1}/data.xml'>

	^((GRCodec forEncoding: 'utf-8') decode: (Orbeon_Form_Data getFormDefinitionWithId: id) xml) asString! !

!WAOrbeonPersistenceApiService methodsFor: 'service-get' stamp: 'BrunoBB 08/17/2015 13:58'!
getFormVersion: formName app: app 
	"This method is called by Orbeon when a Form Definition (inside the Builder) is about to be Published.
	This method answer the latest version of the form definition <formName> in application <app>.
	Using the header <orbeon-form-definition-version> to set the version number.
	It also called when a new Form Instance page is about to be displayed (app/form/new)"
	| latestVersionNumber |
	<get>
	<produces: 'application/xml'>
	<path: '/crud/{2}/{1}/form/form.xhtml'>

	latestVersionNumber := Orbeon_Form_Definition getLatestFormDefinitionVersion: formName app: app.

	self requestContext response headerAt: 'orbeon-form-definition-version' put: latestVersionNumber printString.

	^((GRCodec forEncoding: 'utf-8') decode: (Orbeon_Form_Definition getLatestFormDefinition: formName app: app) xml) asString! !

!WAOrbeonPersistenceApiService methodsFor: 'summary' stamp: 'BrunoBB 08/16/2015 15:15'!
getInstancesTypeFrom: xmlDocument for: username inGroup: group forForm: formName in: app
	| draftsNodes draftNode |

	draftsNodes := xmlDocument descendentElementsNamed: 'drafts'.
	draftsNodes isEmpty ifTrue: [^self getValidInstancesFor: username group: group inForm: formName in: app].

	draftNode := draftsNodes first.
	(((draftNode attributeAt: 'for-never-saved-document') = 'true') and: [draftNode contentString = 'only'])
	ifTrue: [^self getValidDraftsFor: username group: group inForm: formName in: app].

	^self getValidInstancesFor: username group: group inForm: formName in: app! !

!WAOrbeonPersistenceApiService methodsFor: 'service-get' stamp: 'BrunoBB 08/21/2015 10:41'!
getOrbeonFr
	"This service is called when accessing Form Runner Home: ../orbeon/fr/ "
	| xmlWriter |
	<get>
	<produces: 'application/xml'>
	<path: '/form'>

	xmlWriter := XMLWriter new.
	xmlWriter writeWith: [:writer | | tag | 
		writer tag: 'forms' with: [Orbeon_Form_Definition getAllLatestFormDefinitions do: [:eachDef | 
			self getXmlNodeFor: eachDef with: writer]].
	].

	^xmlWriter contents! !

!WAOrbeonPersistenceApiService methodsFor: 'summary' stamp: 'BrunoBB 08/17/2015 14:49'!
getPageNumberFrom: xmlDocument
	| pageNumberNodes pageNumberNode |

	pageNumberNodes := xmlDocument allElementsNamed: 'page-number'.
	pageNumberNodes isEmpty ifTrue: [^1].

	pageNumberNode := pageNumberNodes last.
	pageNumberNode strings isEmpty ifTrue: [^1].

	^Number fromString: pageNumberNode strings last! !

!WAOrbeonPersistenceApiService methodsFor: 'summary' stamp: 'BrunoBB 08/17/2015 14:49'!
getPageSizeFrom: xmlDocument
	| pageSizeNodes pageSizeNode |

	pageSizeNodes := xmlDocument allElementsNamed: 'page-size'.
	pageSizeNodes isEmpty ifTrue: [^10].

	pageSizeNode := pageSizeNodes last.
	pageSizeNode strings isEmpty ifTrue: [^10].

	^Number fromString: pageSizeNode strings last! !

!WAOrbeonPersistenceApiService methodsFor: 'summary' stamp: 'BrunoBB 08/16/2015 16:47'!
getPermissionsFor: anOrbeon_Form_Data user: username group: group in: formDefinition
	| printStream |

	printStream := PrintStream on: String new.

	((anOrbeon_Form_Data hasUser: username createAccessUsing: formDefinition permissions) 
	or: [anOrbeon_Form_Data hasRole: group createAccessUsing: formDefinition permissions])
		ifTrue: [printStream nextPutAll: 'create '].

	((anOrbeon_Form_Data hasUser: username readAccessUsing: formDefinition permissions) 
	or: [anOrbeon_Form_Data hasRole: group readAccessUsing: formDefinition permissions])
		ifTrue: [printStream nextPutAll: 'read '].

	((anOrbeon_Form_Data hasUser: username updateAccessUsing: formDefinition permissions) 
	or: [anOrbeon_Form_Data hasRole: group updateAccessUsing: formDefinition permissions])
		ifTrue: [printStream nextPutAll: 'update '].

	((anOrbeon_Form_Data hasUser: username deleteAccessUsing: formDefinition permissions) 
	or: [anOrbeon_Form_Data hasRole: group deleteAccessUsing: formDefinition permissions])
		ifTrue: [printStream nextPutAll: 'delete '].

	^printStream contents! !

!WAOrbeonPersistenceApiService methodsFor: 'summary' stamp: 'BrunoBB 08/16/2015 15:02'!
getQueryNodesFrom: xmlDocument
	"The receiver extract the -query nodes- from the XML Document <xmlDocument>.
	These -query nodes- are used to query the Orbeon Summary and to show summary fields"
	| queryNodes |

	queryNodes := OrderedCollection new.

	(xmlDocument allElementsNamed: 'query') do: [:node | | queryNode value |
		value := node strings notEmpty ifTrue: [node strings last] ifFalse: [nil].
		queryNode := OrbeonQueryNode new name: (node attributeAt: 'name');
								path: (node attributeAt: 'path');
								type: (node attributeAt: 'type');
								control: (node attributeAt: 'control');
								searchField: (node attributeAt: 'search-field'); 
								summaryField: (node attributeAt: 'summary-field'); 
								match: (node attributeAt: 'match'); 
								value: value;
								yourself.
		queryNodes add: queryNode.
		].

	^queryNodes! !

!WAOrbeonPersistenceApiService methodsFor: 'summary' stamp: 'BrunoBB 08/16/2015 15:20'!
getValidDraftsFor: username group: group inForm: formName in: app
	"Answer a collection of valid drafts for the form <formName> in application <app> for the current user <username> that belongs to the group <group>.
	For more details: https://github.com/orbeon/orbeon-forms/wiki/Form-Runner-~-Autosave"
	| definition |

	definition := Orbeon_Form_Definition getLatestFormDefinition: formName app: app.

	^((Orbeon_Form_Data getFormDraftsOf: formName in: app) 
			select: [:each | (each hasUser: username readAccessUsing: definition permissions) 
										or: [each hasRole: group readAccessUsing: definition permissions]])! !

!WAOrbeonPersistenceApiService methodsFor: 'summary' stamp: 'BrunoBB 08/16/2015 15:11'!
getValidInstancesFor: username group: group inForm: formName in: app
	"Answer a collection of valid instances for the form <formName> in application <app> for the current user <username> that belongs to the group <group>"
	| definition |

	definition := Orbeon_Form_Definition getLatestFormDefinition: formName app: app.

	^((Orbeon_Form_Data getFormInstancesOf: formName in: app) 
			select: [:each | each deleted = 'N' and: [(each hasUser: username readAccessUsing: definition permissions) 
																	or: [each hasRole: group readAccessUsing: definition permissions]]]) 
		addAll:
		((Orbeon_Form_Data getFormDraftsOf: formName in: app) 
			select: [:each | (each hasUser: username readAccessUsing: definition permissions) 
									or: [each hasRole: group readAccessUsing: definition permissions]]);
		yourself! !

!WAOrbeonPersistenceApiService methodsFor: 'summary' stamp: 'BrunoBB 08/17/2015 13:10'!
getXmlNodeFor: anOrbeon_Form_Definition with: anXMLWriter

	anXMLWriter tag: 'form' with: [
		anXMLWriter tag: 'application-name' with: anOrbeon_Form_Definition app.
		anXMLWriter tag: 'form-name' with: anOrbeon_Form_Definition form.
		anXMLWriter tag: 'title' with: anOrbeon_Form_Definition title.
		anXMLWriter tag: 'description' with: anOrbeon_Form_Definition description.
		anXMLWriter tag: 'last-modified-time' with: anOrbeon_Form_Definition last_modified_time asOrbeonDateTimeString.
		anXMLWriter tag: 'available' with: anOrbeon_Form_Definition available.
	].! !

!WAOrbeonPersistenceApiService methodsFor: 'service-get' stamp: 'BrunoBB 08/16/2015 17:19'!
getXmlOfFormDraftWithId: id form: form app: app
	"This service is called when a click is performed on the Orbeon Form Summary page.
	The Summary then should open the Form Instance (view/edit mode ) in the corresponding form definition (template).
	This sevice is used in combination with #getDefinitionForFormInstanceWithId:form:app: that <get> the form definition (template) to the form with id <id>"
	| orbeonInstance definition permissions username group |
	<get>
	<produces: 'application/xml'>
	<path: '/crud/{3}/{2}/draft/{1}/data.xml'>

	definition := Orbeon_Form_Definition getLatestFormDefinition: form app: app.
	orbeonInstance := Orbeon_Form_Data getFormDraft: form in: app withId: id.
	group := self requestContext request headerAt: 'orbeon-group'.
	username := self requestContext request headerAt: 'orbeon-username'.
	permissions := self getPermissionsFor: orbeonInstance user: username group: group in: definition.
	
	self requestContext response headerAt: 'orbeon-operations' put: permissions.

	^((GRCodec forEncoding: 'utf-8') decode: orbeonInstance xml) asString! !

!WAOrbeonPersistenceApiService methodsFor: 'service-get' stamp: 'BrunoBB 08/16/2015 17:20'!
getXmlOfFormInstanceWithId: id form: form app: app
	"This service is called when a click is performed on the Orbeon Form Summary page.
	The Summary then should open the Form Instance (view/edit mode ) in the corresponding form definition (template).
	This sevice is used in combination with #getDefinitionForFormInstanceWithId:form:app: that <get> the form definition (template) to the form with id <id>"
	| orbeonInstance definition permissions username group |
	<get>
	<produces: 'application/xml'>
	<path: '/crud/{3}/{2}/data/{1}/data.xml'>

	definition := Orbeon_Form_Definition getLatestFormDefinition: form app: app.
	orbeonInstance := Orbeon_Form_Data getFormInstance: form in: app withId: id.
	group := self requestContext request headerAt: 'orbeon-group'.
	username := self requestContext request headerAt: 'orbeon-username'.
	permissions := self getPermissionsFor: orbeonInstance user: username group: group in: definition.

	self requestContext response headerAt: 'orbeon-operations' put: permissions.

	^((GRCodec forEncoding: 'utf-8') decode: orbeonInstance xml) asString! !

!WAOrbeonPersistenceApiService methodsFor: 'other' stamp: 'BrunoBB 08/05/2015 12:37'!
hardCodeAnswer

	^'<documents xmlns:ev="http://www.w3.org/2001/xml-events" xmlns:f="http//www.orbeon.com/function" xmlns:frf="java:org.orbeon.oxf.fr.FormRunner" xmlns:odt="http://orbeon.org/oxf/xml/datatypes" xmlns:oxf="http://www.orbeon.com/oxf/processors" xmlns:p="http://www.orbeon.com/oxf/pipeline" xmlns:saxon="http://saxon.sf.net/" xmlns:sql="http://orbeon.org/oxf/xml/sql" xmlns:xf="http://www.w3.org/2002/xforms" xmlns:xi="http://www.w3.org/2001/XInclude" xmlns:xpl="java:org.orbeon.oxf.pipeline.api.FunctionLibrary" xmlns:xs="http://www.w3.org/2001/XMLSchema" xmlns:xxf="http://orbeon.org/oxf/xml/xforms" search-total="9" total="9">
	<document created="2015-07-15T22:11:24.849Z" draft="N" last-modified="2015-07-21T20:35:59.893Z" name="1526e81d6d405ec1ac1d4849f7cacfa18572220c" operations="*">
		<details>
			<detail>ue</detail>
			<detail>complete-test</detail>
			<detail>Complete Test</detail>
			<detail/>
		</details>
	</document>
	<document created="2015-06-13T23:44:05.993Z" draft="N" last-modified="2015-06-13T23:45:26.604Z" name="2e387e31fb83fb21d996708dc2c66c5e599ff4a1" operations="*">
		<details>
			<detail>ue</detail>
			<detail>procesar-permiso-general</detail>
			<detail>Procesar Permiso General</detail>
			<detail/>
		</details>
	</document>
	<document created="2015-06-13T23:41:57.945Z" draft="N" last-modified="2015-06-13T23:46:04.939Z" name="a233448a57a88e4d5d38fe8ad154832a82c96386" operations="*">
		<details>
			<detail>ue</detail>
			<detail>analisis-contruccion</detail>
			<detail>Analisis Construccion</detail>
			<detail/>
		</details>
	</document>
	<document created="2015-06-03T13:56:33.557Z" draft="N" last-modified="2015-06-03T19:01:44.747Z" name="bd1a4d6216254db2c2e46e6612b7c4b2eabaa726" operations="*">
		<details>
			<detail>ue</detail>
			<detail>resultado-permiso</detail>
			<detail>Resultado Permiso Construccion</detail>
			<detail/>
		</details>
	</document>
	<document created="2015-06-03T13:55:23.270Z" draft="N" last-modified="2015-06-03T19:00:57.204Z" name="6bfcdc725198640914adbb169b848c3651f182d9" operations="*">
		<details>
			<detail>ue</detail>
			<detail>analisis-estructura</detail>
			<detail>Analisis Estructura</detail>
			<detail/>
		</details>
	</document>
	<document created="2015-06-03T13:47:33.837Z" draft="N" last-modified="2015-06-03T19:00:17.169Z" name="8aaa73a2b8bfc710b4762e96597c62a2dbcfe7c0" operations="*">
		<details>
			<detail>ue</detail>
			<detail>procesar-permiso-fabrica</detail>
			<detail>Procesar Permiso FABRICA</detail>
			<detail/>
		</details>
	</document>
	<document created="2015-06-03T13:46:42.458Z" draft="N" last-modified="2015-06-03T18:59:40.262Z" name="bddc4e7171bfb0fe6d278f7694d2bb33e0e840a6" operations="*">
		<details>
			<detail>ue</detail>
			<detail>procesar-permiso-edificio</detail>
			<detail>Procesar Permiso Edificio</detail>
			<detail/>
		</details>
	</document>
	<document created="2015-06-03T13:45:45.653Z" draft="N" last-modified="2015-06-03T18:59:02.697Z" name="32f1b9377c2cc04d799aa5e3dd6b9c0ad6a68780" operations="*">
		<details>
			<detail>ue</detail>
			<detail>procesar-permiso-casa</detail>
			<detail>Procesar Permiso Casa</detail>
			<detail/>
		</details>
	</document>
	<document created="2015-06-03T13:44:39.982Z" draft="N" last-modified="2015-06-03T18:57:01.444Z" name="31c81f6274d68dce5f5e14e9efc163f32b2145dd" operations="*">
		<details>
			<detail>ue</detail>
			<detail>peticion-permiso-construccion</detail>
			<detail>Peticion Permiso Construccion</detail>
			<detail/>
		</details>
	</document>
</documents>'! !

!WAOrbeonPersistenceApiService methodsFor: 'other' stamp: 'BrunoBB 08/12/2015 15:07'!
hardCodeAnswer2

	^'<?xml version="1.0" encoding="UTF-8"?><forms><form>
        <application-name>orbeon</application-name>
        <form-name>w9</form-name>
        <title xml:lang="en">Request for Taxpayer Identification Number and Certification</title>
        <description xml:lang="en"/>
        <last-modified-time>2015-05-05T19:12:33.711-04:00</last-modified-time>
    </form><form>
        <application-name>orbeon</application-name>
        <form-name>library</form-name>
        <title xml:lang="en">Global Library</title>
        <description xml:lang="en">This special form contains the global Form Builder library of section templates accessible from all forms.</description>
        <title xml:lang="fr">Bibliothque globale</title>
        <description xml:lang="fr">Ce formulaire spcial contient la bibliothque global de Form Builder, avec les modles de sections disponibles depuis tous les formulaires.</description>
        <logo mediatype="" filename="" size=""/>
        <last-modified-time>2015-05-05T19:12:33.567-04:00</last-modified-time>
    </form><form>
        <application-name>orbeon</application-name>
        <form-name>controls</form-name>
        <title xml:lang="en">Form Builder Controls</title>
        <description xml:lang="en">This form shows all the built-in controls supported by Form Builder</description>
        <title xml:lang="fr">Contrles de Form Builder</title>
        <description xml:lang="fr">Ce formulaire montre tous les contrles supports par Form Builder</description>
        <last-modified-time>2015-05-05T19:12:33.178-04:00</last-modified-time>
    </form><form>
        <application-name>orbeon</application-name>
        <form-name>contact</form-name>
        <title xml:lang="en">Contact</title>
        <description xml:lang="en">The Contact form is a simple form which can be created in a few minutes with Form Builder.</description>
        <title xml:lang="fr">Contact</title>
        <description xml:lang="fr">Le formulaire Contact peut tre cr  laide de Form Builder en quelques minutes.</description>
        <last-modified-time>2015-05-05T19:12:33.011-04:00</last-modified-time>
    </form><form>
        <application-name>orbeon</application-name>
        <form-name>bookshelf</form-name>
        <title xml:lang="en">Orbeon Forms Bookshelf</title>
        <description xml:lang="en">Orbeon Forms Bookshelf is a simple form allowing you to gather information about books.</description>
        <title xml:lang="fr">Orbeon Forms Bookshelf</title>
        <description xml:lang="fr">Orbeon Forms Bookshelf prsente un formulaire simple qui vous permet de saisir des informations sur des livres.</description>
        <migration version="4.8.0">[{ "path": "notes/note", "iteration-name": "note-iteration" }]</migration>
        <last-modified-time>2015-05-05T19:12:29.311-04:00</last-modified-time>
    </form></forms>'! !

!WAOrbeonPersistenceApiService methodsFor: 'service-put' stamp: 'BrunoBB 08/18/2015 13:59'!
publishFormDefinition: formName app: app withId: documentId
	"This method is called by Orbeon when a Form Definition has been published with form name <formName> in application <app> with form id <documentId>"
	| orbeonDefinition headerVersion currentVersion |
	<put>
	<consumes: 'application/xml'>
	<path: '/crud/{2}/{1}/form/form.xhtml?document={3}'>

	orbeonDefinition := Orbeon_Form_Definition new.
	orbeonDefinition parentInstance: (Orbeon_Form_Data getFormDefinition: formName in: app withId: documentId ifNone: [nil]).

	headerVersion := (self requestContext request headerAt: 'orbeon-form-definition-version').
	currentVersion := Orbeon_Form_Definition getLatestFormDefinitionVersion: formName app: app.
	"Orbeon put -next- when a new version is going to be generated if NOT --> the current version is updated"
	(headerVersion = 'next') ifTrue: [currentVersion := currentVersion + 1].

	orbeonDefinition xml: self requestContext request rawBody;
		updateLastModifiedTime;
		form_version: currentVersion;
		setMetadata;
		available: 'true';
		addToStorage.! !

!WAOrbeonPersistenceApiService methodsFor: 'service-put' stamp: 'BrunoBB 08/24/2015 12:48'!
receiveAndPublishFileFor: formName app: app documentId: documentId fileId: fileId
	"This service is called when a user click -Publish- form in Orbeon Form Builder and the form definition has attached files.
	The Form Definition is <formName> in the Orbeon Application <app> where the id of the form definition is <documentId> and the attached file id is <fileId>.
	This service is called for each attached fiel in the Form Definition. 
	The attached file is stored in the repository"
	| gsFile |
	<put>
	<path: '/crud/{2}/{1}/form/{4}?document={3}'>

	gsFile := GsFile open: ('/opt/orbeon-files/definitions/published/', fileId) mode: 'wb' onClient: false.

	gsFile
		nextPutAll: self requestContext request rawBody;
		flush;
		close.! !

!WAOrbeonPersistenceApiService methodsFor: 'service-put' stamp: 'BrunoBB 08/24/2015 12:48'!
receiveAndSaveFileForDefinitionWithId: definitionId fileId: fileId valid: aBoolean
	"This service receives a file with id <fileId> from Orbeon Form Builder when the a user clicked -Save-.
	The file was uploaded into a Form Definition as a Custom PDF or as direct file Upload.
	A direct file upload is when a File Attachment is added to a Form Definition and a concrete file is also uploaded"
	| stream gsFile |
	<put>
	<path: '/crud/orbeon/builder/data/{1}/{2}.bin?valid={3}'>

	gsFile := GsFile open: ('/opt/orbeon-files/definitions/saved/', fileId, '.bin') mode: 'wb' onClient: false.

	gsFile
		nextPutAll: self requestContext request rawBody;
		flush;
		close.! !

!WAOrbeonPersistenceApiService methodsFor: 'service-put' stamp: 'BrunoBB 08/24/2015 12:48'!
receiveAndSaveFileForDraft: formName app: app definitionId: definitionId fileId: fileId valid: aBoolean
	"This service is called from Orbeon Form Runner -new/edit- when a file is uploaded (and autosave is -true-) to a Form Instance.
	When the form is autosaved then all form's attachments are sent to this service "
	| stream gsFile |
	<put>
	<path: '/crud/{2}/{1}/draft/{3}/{4}?valid={5}'>

	gsFile := GsFile open: ('/opt/orbeon-files/drafts/', fileId) mode: 'wb' onClient: false.

	gsFile
		nextPutAll: self requestContext request rawBody;
		flush;
		close.! !

!WAOrbeonPersistenceApiService methodsFor: 'service-put' stamp: 'BrunoBB 08/24/2015 12:49'!
receiveAndSaveFileForInstance: formName app: app definitionId: definitionId fileId: fileId valid: aBoolean
	"This service is called from Orbeon Form Runner -new/edit- when a file is uploaded to a Form Instance.
	When the form is sent then all form's attachments are sent to this service"
	| stream gsFile |
	<put>
	<path: '/crud/{2}/{1}/data/{3}/{4}?valid={5}'>

	gsFile := GsFile open: ('/opt/orbeon-files/instances/', fileId) mode: 'wb' onClient: false.

	gsFile
		nextPutAll: self requestContext request rawBody;
		flush;
		close.! !

!WAOrbeonPersistenceApiService methodsFor: 'service-put' stamp: 'BrunoBB 08/24/2015 16:40'!
saveDraftFormInstance: formName app: app withId: id valid: aBoolean
	"This method is called by Orbeon when a Form is autosaved in a Form Instance page"
	| orbeonDraft |
	<put>
	<produces: 'application/xml'>
	<path: '/crud/{2}/{1}/draft/{3}/data.xml?valid={4}'>

	orbeonDraft := Orbeon_Form_Data new. "we preserve the existing form instance so we create a new one"

	orbeonDraft xml: self requestContext request rawBody;
		app: app;
		form: formName;
		draft: 'Y';
		document_id: id;
		form_version: (self requestContext request headerAt: 'orbeon-form-definition-version');
		username:  (self requestContext request headerAt: 'orbeon-username'); "BUG - creator set only one time"
		last_modified_by: (self requestContext request headerAt: 'orbeon-username');
		groupname: (self requestContext request headerAt: 'orbeon-group');
		updateLastModifiedTime;
		addToStorageAsDraft.! !

!WAOrbeonPersistenceApiService methodsFor: 'service-put' stamp: 'BrunoBB 08/16/2015 12:06'!
saveFinalFormInstance: formName app: app withId: id valid: aBoolean
	"This method is called by Orbeon when a user click 'Send' in a Form Instance page"
	| orbeonInstance |
	<put>
	<produces: 'application/xml'>
	<path: '/crud/{2}/{1}/data/{3}/data.xml?valid={4}'>

	orbeonInstance := Orbeon_Form_Data getFormInstance: formName in: app withId: id ifNone: [Orbeon_Form_Data new].

	orbeonInstance xml: self requestContext request rawBody;
		app: app;
		form: formName;
		document_id: id;
		form_version: (self requestContext request headerAt: 'orbeon-form-definition-version');
		username:  (self requestContext request headerAt: 'orbeon-username'); "BUG - creator set only one time"
		last_modified_by: (self requestContext request headerAt: 'orbeon-username');
		groupname: (self requestContext request headerAt: 'orbeon-group');
		updateLastModifiedTime;
		addToStorage.
	"we already saved a final version --> there is NO more draft left in storage. we must remove it"
	orbeonInstance removeFromStorageAsDraft.! !

!WAOrbeonPersistenceApiService methodsFor: 'service-put' stamp: 'BrunoBB 08/27/2015 18:05'!
saveInFormBuilderDefinitionWithId: id valid: aBoolean
	"This service is called by Orbeon when a user click on -Save- inside the Form Builder.
	A Form Definition has been saved "
	| orbeonData |
	<put>
	<path: '/crud2/orbeon/builder/data/{1}/data.xml/?valid={2}'>

	orbeonData := Orbeon_Form_Data getFormInstanceWithId: id ifNone: [Orbeon_Form_Data new].

	orbeonData xml: self requestContext request rawBody;
		isDefinition: true;
		document_id: id;
		form_version: (self requestContext request headerAt: 'orbeon-form-definition-version');
		updateLastModifiedTime;
		setMetadata;
		addToStorage.! !

!WAOrbeonPersistenceApiService methodsFor: 'service-post' stamp: 'BrunoBB 08/17/2015 15:36'!
searchInFormBuilderSummary
	"This service is called by Orbeon when rendering an Orbeon Form Builder Summary page and
	answer a well formatted XML with the result of the query received in the request.
	This XML is going to be displayed in the Orbeon Form Builder Summary page"	
	| xmlDocument definitions pageSize pageNumber from to |
	<post>
	<produces: 'application/xml'>
	<path: '/search/orbeon/builder'>

	xmlDocument := XMLDOMParser parse: self requestContext request rawBody.
	definitions := self applyQueryToFormDefinition: xmlDocument.
	pageSize := self getPageSizeFrom: xmlDocument.
	pageNumber := self getPageNumberFrom: xmlDocument.
	to := pageSize * pageNumber.
	from := to - pageSize + 1.
	to := (to>= definitions size) ifTrue: [definitions size] ifFalse: [to].

	^self generateXmlAnswerForBuilderSummary: (definitions copyFrom: from to: to)
			searchTotal: definitions size! !

!WAOrbeonPersistenceApiService methodsFor: 'service-post' stamp: 'BrunoBB 08/21/2015 11:04'!
searchInFormSummary: formName app: app
	"This service is called by Orbeon when rendering an Orbeon Form Summary page and
	answer a well formatted XML with the result of the query received in the request.
	This XML is going to be displayed in the Orbeon Form Summary page"
	| xmlDocument queryNodes instances group username definition filteredInstances pageSize pageNumber from to |
	<post>
	<produces: 'application/xml'>
	<path: '/search/{2}/{1}'>

	xmlDocument := XMLDOMParser parse: self requestContext request rawBody.
	queryNodes := self getQueryNodesFrom: xmlDocument.
	group := self requestContext request headerAt: 'orbeon-group'.
	username := self requestContext request headerAt: 'orbeon-username'.
	instances := self getInstancesTypeFrom: xmlDocument for: username inGroup: group forForm: formName in: app.
	definition := Orbeon_Form_Definition getLatestFormDefinition: formName app: app.
	"here apply the filters for that entered in the web application for search purpose (example: id=123456)"
	filteredInstances := self applyQueryToFormInstance: instances queryNodes: queryNodes.

	pageSize := self getPageSizeFrom: xmlDocument.
	pageNumber := self getPageNumberFrom: xmlDocument.
	to := pageSize * pageNumber.
	from := to - pageSize + 1.
	to := (to>= filteredInstances size) ifTrue: [filteredInstances size] ifFalse: [to].

	^self generateXmlAnswerFor: definition
				summary: (filteredInstances copyFrom: from to: to)
				withQueryNodes: queryNodes
				user: username
				group: group
				searchTotal: filteredInstances size! !

!WAOrbeonPersistenceApiService methodsFor: 'other' stamp: 'BrunoBB 08/04/2015 13:28'!
seasideMimeDocument

	^WAMimeDocument on: 'OK' mimeType: WAMimeType textPlain! !

!WAOrbeonPersistenceApiService methodsFor: 'service-get' stamp: 'BrunoBB 08/24/2015 13:01'!
sendFileForDefinitionWithId: definitionId fileId: fileId
	"This service is called by Orbeon Form Builder to get/obtain the attached file with id <fileId> for the Form Definition <definitionId>.
	The service answer an octet stream to the caller."
	| contents gsFile |
	<get>
	<produces: 'application/octet-stream'>
	<path: '/crud/orbeon/builder/data/{1}/{2}'>

	self requestContext response contentType: WAMimeType applicationOctetStream.

	gsFile := GsFile openOnServer: ('/opt/orbeon-files/definitions/saved/', fileId) mode: 'rb'.
	contents := gsFile contentsAsUtf8.

	gsFile close.

	^contents! !

!WAOrbeonPersistenceApiService methodsFor: 'service-get' stamp: 'BrunoBB 08/24/2015 16:44'!
sendFileForDraft: formName app: app definitionId: definitionId fileId: fileId
	"This service is called when rendering the Draft of the form in Form Instance page"
	| contents gsFile |
	<get>
	<produces: 'application/octet-stream'>
	<path: '/crud/{2}/{1}/draft/{3}/{4}'>

	self requestContext response contentType: WAMimeType applicationOctetStream.

	gsFile := GsFile openOnServer: ('/opt/orbeon-files/drafts/', fileId) mode: 'rb'.
	contents := gsFile contentsAsUtf8.

	gsFile close.

	^contents! !

!WAOrbeonPersistenceApiService methodsFor: 'service-get' stamp: 'BrunoBB 08/24/2015 16:44'!
sendFileForInstance: formName app: app definitionId: definitionId fileId: fileId
	"This service is called when rendering the form Instance in Form Instance page"
	| contents gsFile |
	<get>
	<produces: 'application/octet-stream'>
	<path: '/crud/{2}/{1}/data/{3}/{4}'>

	self requestContext response contentType: WAMimeType applicationOctetStream.

	gsFile := GsFile openOnServer: ('/opt/orbeon-files/instances/', fileId) mode: 'rb'.
	contents := gsFile contentsAsUtf8.

	gsFile close.

	^contents! !

!WAOrbeonPersistenceApiService methodsFor: 'service-get' stamp: 'BrunoBB 08/27/2015 17:40'!
sendFileForInstance: formName app: app fileId: fileId
	"This service is called when Orbeon requires a Custom PDF of a form or the Form Instance has any attachments and the user has clicked -Send-"
	| contents gsFile |
	<get>
	<produces: 'application/octet-stream'>
	<path: '/borrar-esto/crud/{2}/{1}/form/{3}'>

	self requestContext response contentType: WAMimeType applicationOctetStream.

	gsFile := GsFile openOnServer: ('/opt/orbeon-files/definitions/published/', fileId) mode: 'rb'.
	contents := gsFile contentsAsUtf8.

	gsFile close.

	^contents! !

!WAOrbeonPersistenceApiService methodsFor: 'service-put' stamp: 'BrunoBB 08/20/2015 11:26'!
unpublishFormDefinition: formName app: app
	"This method is called by Orbeon when a Form Definition has been unpublished with form name <formName> in application <app>"
	<put>
	<path: '/crud/{2}/{1}/form/form.xhtml'>

	(Orbeon_Form_Definition getLatestFormDefinition: formName app: app) 
		switchAvailable

"	(Orbeon_Form_Definition getLatestFormDefinition: formName app: app) xml: self requestContext request rawBody"! !

WARestfulHandler subclass: #WAOrbeonPersistenceLayer
	instanceVariableNames: ''
	classVariableNames: ''
	poolDictionaries: ''
	category: 'Orbeon_Persistence_API'!

!WAOrbeonPersistenceLayer methodsFor: 'other' stamp: 'BrunoBB 09/03/2015 14:01'!
apiConfiguration

	^OrbeonApiConfiguration default! !

!WAOrbeonPersistenceLayer methodsFor: 'summary' stamp: 'BrunoBB 08/27/2015 12:04'!
applyQueryToFormDefinition: xmlDocument
	| queryNodes queryFields result |

	queryFields  := Dictionary new.
	result := OrbeonApplication getAllSavedDefinitions select: [:each | each deleted = 'N'].

	queryNodes := (xmlDocument allElementsNamed: 'query') do: [:node | 
		node strings notEmpty ifTrue: [queryFields at: (node attributeAt: 'name') put: node strings last]].

	queryFields keysAndValuesDo: [:key :value |
		(key = 'application-name') ifTrue: [result := result select: [:each | each app = (queryFields at: 'application-name')]].
		(key = 'form-name') ifTrue: [result := result select: [:each | each form = (queryFields at: 'form-name')]].
		(key = 'title') ifTrue: [result := result select: [:each | each title = (queryFields at: 'title')]].
		(key = 'description') ifTrue: [result := result select: [:each | each description = (queryFields at: 'description')]].
	].

	^result! !

!WAOrbeonPersistenceLayer methodsFor: 'summary' stamp: 'BrunoBB 08/25/2015 16:01'!
applyQueryToFormInstance: instances queryNodes: collectionOfOrbeonQueryNode
	|  query |

	query := collectionOfOrbeonQueryNode select: [:each | each isSearchAndHasValue].

	^(instances select: [:each | each satisfyQuery: query]) asOrderedCollection! !

!WAOrbeonPersistenceLayer methodsFor: 'other' stamp: 'BrunoBB 08/26/2015 17:55'!
createOrbeonApplicationNamed: appName

	^OrbeonApplication new
		app: appName;
		addToCache;
		yourself! !

!WAOrbeonPersistenceLayer methodsFor: 'service-delete' stamp: 'BrunoBB 09/02/2015 14:16'!
deleteFormDefinitionWithId: id
	"This method is called by Orbeon when a user click 'Send' in a Form Instance page"
	| orbeonInstance |
	<delete>
	<path: '/crud/orbeon/builder/data/{1}/data.xml'>

	OrbeonApplication logicalRemoveDefinitionWithId: id ifNone: [nil]! !

!WAOrbeonPersistenceLayer methodsFor: 'service-delete' stamp: 'BrunoBB 09/02/2015 14:58'!
deleteFormDraft: formName app: app withId: id
	"This method is called by Orbeon when a user click 'Send' in a Form Instance page"
	| application definition instances |
	<delete>
	<path: '/crud/{2}/{1}/draft/{3}/data.xml'>

	application := OrbeonApplication applicationNamed: app ifNone: [^NoOrbeonAppException signal: 'No application named [', app, '] was found'].
	definition := OrbeonApplication formDefinitionNamed: formName in: app.
	instances := definition getDraftWithId: id ifNone: [^self].

	instances logicalDelete! !

!WAOrbeonPersistenceLayer methodsFor: 'service-delete' stamp: 'BrunoBB 09/02/2015 14:58'!
deleteFormInstance: formName app: app withId: id
	"This method is called by Orbeon when a user click -Send- in a Form Instance page"
	| application definition instance |
	<delete>
	<path: '/crud/{2}/{1}/data/{3}/data.xml'>

	application := OrbeonApplication applicationNamed: app ifNone: [^NoOrbeonAppException signal: 'No application named [', app, '] was found'].
	definition := OrbeonApplication formDefinitionNamed: formName in: app.
	instance := definition getInstanceWithId: id ifNone: [^self].

	instance logicalDelete! !

!WAOrbeonPersistenceLayer methodsFor: 'service-put' stamp: 'BrunoBB 09/02/2015 15:31'!
duplicateFormDefinitionNewId: id
	""
	| application instanceDefinition currentDefinition |
	<put>
	<produces: 'application/xml'>
	<path: '/crud/orbeon/builder/data/{1}/data.xml'>

	instanceDefinition := OrbeonFormInstanceDefinition new.

	instanceDefinition xmlString: self requestContext request rawBody;
		id: id;
		setApplicationAndFormName;
		version: (self requestContext request headerAt: 'orbeon-form-definition-version');
		updateLastModifiedTime.

	application := OrbeonApplication 
							applicationNamed: instanceDefinition app
							ifNone: [^NoOrbeonAppException signal: 'No such application [', instanceDefinition app, ']'].

	currentDefinition := application getLatestSavedDefinition: instanceDefinition form.
	instanceDefinition setXmlString: instanceDefinition xmlString; "create the associated OrbeonFormDefinition"
		title: currentDefinition title;
		description: currentDefinition description.

	application addSavedDefinition: instanceDefinition! !

!WAOrbeonPersistenceLayer methodsFor: 'service-put' stamp: 'BrunoBB 09/02/2015 15:03'!
duplicateFormInstance: formName app: app newId: id
	"This method is called by Orbeon when a user click 'Send' in a Form Instance page"
	| orbeonInstance |
	<put>
	<produces: 'application/xml'>
	<path: '/crud/{2}/{1}/data/{3}/data.xml'>

	orbeonInstance := OrbeonFormInstance new.

	orbeonInstance xml: self requestContext request rawBody;
		app: app;
		form: formName;
		id: id;
		version: (self requestContext request headerAt: 'orbeon-form-definition-version');
		updateLastModifiedTime.! !

!WAOrbeonPersistenceLayer methodsFor: 'summary' stamp: 'BrunoBB 08/25/2015 16:01'!
generateXmlAnswerFor: formDefinition summary: instanceCollection withQueryNodes: collectionOfOrbeonQueryNode user: username group: group searchTotal: searchTotal
	| xmlWriter summaryFields |

	xmlWriter := XMLWriter new.
	summaryFields := collectionOfOrbeonQueryNode select: [:each | each isSummary] thenCollect: [:each | each name].

	xmlWriter writeWith: [:writer | | tag |
		tag := writer tag: 'documents' attributes: (self getArrayOfOrbeonHeadersFor: instanceCollection searchTotal: searchTotal).
		tag with: [instanceCollection do: [:each | self generateXmlNodeFor: each definition: formDefinition summary: summaryFields with: writer user: username group: group]].
	].

	 ^xmlWriter contents! !

!WAOrbeonPersistenceLayer methodsFor: 'summary' stamp: 'BrunoBB 08/25/2015 16:01'!
generateXmlAnswerForBuilderSummary: definitionCollection searchTotal: searchTotal
	| xmlWriter |

	xmlWriter := XMLWriter new.

	xmlWriter writeWith: [:writer | | tag |
		tag := writer tag: 'documents' attributes: (self getArrayOfOrbeonHeadersFor: definitionCollection searchTotal: searchTotal).
		tag with: [definitionCollection do: [:each | self generateXmlNodeForDefinition: each with: writer]].
	].

	 ^xmlWriter contents! !

!WAOrbeonPersistenceLayer methodsFor: 'summary' stamp: 'BrunoBB 09/01/2015 13:49'!
generateXmlNodeFor: anOrbeonFormInstance definition: formDefinition summary: collectionOfNames with: aXMLWriter user: username group: group
	| nodeAttributes tag |

	nodeAttributes := OrderedCollection new
		add: 'created' -> anOrbeonFormInstance createdTime asOrbeonDateTimeString;
		add: 'draft' -> anOrbeonFormInstance printDraft;
		add: 'last-modified' -> anOrbeonFormInstance modifiedTime asOrbeonDateTimeString;
		add: 'name' -> anOrbeonFormInstance id;
		add: 'operations' -> (self getPermissionsFor: anOrbeonFormInstance user: username group: group in: formDefinition);
		asArray.

	tag := aXMLWriter tag: 'document' attributes: nodeAttributes.

	tag with: [aXMLWriter 
						tag: 'details' 
						with: [(anOrbeonFormInstance getValueOfFields: collectionOfNames) 
									do: [:each | aXMLWriter tag: 'detail' with: each]]].! !

!WAOrbeonPersistenceLayer methodsFor: 'summary' stamp: 'BrunoBB 08/30/2015 17:01'!
generateXmlNodeForDefinition: anOrbeonFormInstanceDefinition with: aXMLWriter
	| nodeAttributes tag |

	nodeAttributes := OrderedCollection new
		add: 'created' -> anOrbeonFormInstanceDefinition createdTime asOrbeonDateTimeString;
		add: 'draft' -> anOrbeonFormInstanceDefinition printDraft;
		add: 'last-modified' -> anOrbeonFormInstanceDefinition modifiedTime asOrbeonDateTimeString;
		add: 'name' -> anOrbeonFormInstanceDefinition id;
		add: 'operations' -> '*';
		asArray.

	tag := aXMLWriter tag: 'document' attributes: nodeAttributes.

	tag with: [aXMLWriter tag: 'details' 
									with: [aXMLWriter tag: 'detail' with: anOrbeonFormInstanceDefinition app.
											aXMLWriter tag: 'detail' with: anOrbeonFormInstanceDefinition form.
											aXMLWriter tag: 'detail' with: anOrbeonFormInstanceDefinition title.
											aXMLWriter tag: 'detail' with: anOrbeonFormInstanceDefinition description.]]! !

!WAOrbeonPersistenceLayer methodsFor: 'other' stamp: 'BrunoBB 08/26/2015 17:10'!
getApplicationNameFrom: xmlDocument ifNone: aBlock

	^(xmlDocument findElementNamed: 'application-name')
		ifNotNil: [:value | value strings isEmpty ifTrue: aBlock ifFalse: [value strings last]]
		ifNil: aBlock.! !

!WAOrbeonPersistenceLayer methodsFor: 'summary' stamp: 'BrunoBB 08/25/2015 16:01'!
getArrayOfOrbeonHeadersFor: anOrderedCollection searchTotal: searchTotal

	^OrderedCollection new
		add: 'xmlns:ev' -> 'http://www.w3.org/2001/xml-events';
		add: 'xmlns:f' -> 'http//www.orbeon.com/function';
		add: 'xmlns:frf' -> 'java:org.orbeon.oxf.fr.FormRunner';
		add: 'xmlns:odt' -> 'http://orbeon.org/oxf/xml/datatypes';
		add: 'xmlns:oxf' -> 'http://www.orbeon.com/oxf/processors';
		add: 'xmlns:p' -> 'http://www.orbeon.com/oxf/pipeline';
		add: 'xmlns:saxon' -> 'http://saxon.sf.net/';
		add: 'xmlns:sql' -> 'http://orbeon.org/oxf/xml/sql';
		add: 'xmlns:xf' -> 'http://www.w3.org/2002/xforms';
		add: 'xmlns:xi' -> 'http://www.w3.org/2001/XInclude';
		add: 'xmlns:xpl' -> 'java:org.orbeon.oxf.pipeline.api.FunctionLibrary';
		add: 'xmlns:xs' -> 'http://www.w3.org/2001/XMLSchema';
		add: 'xmlns:xxf' -> 'http://orbeon.org/oxf/xml/xforms';
		add: 'page-size' -> '10';
		add: 'total' -> Orbeon_Form_Data totalSize printString;
		add: 'search-total' -> searchTotal printString;
		asArray! !

!WAOrbeonPersistenceLayer methodsFor: 'service-get' stamp: 'BrunoBB 09/01/2015 14:04'!
getDefinitionForFormInstanceWithId: id form: form app: app
	"This service is called when a click is performed on the Orbeon Form Summary page (or go directly to edit/view page of a form). The Summary then open the Form Instance in it's corresponding form definition.
	This service is used in combination of #getXmlOfFormInstanceWithId:form:app: to <get> the actual data of the form"
	| application orbeonDefinition latestVersionNumber |
	<get>
	<produces: 'application/xml'>
	<path: '/crud/{3}/{2}/form/form.xhtml?document={1}'>

	application := OrbeonApplication applicationNamed: app ifNone: [^NoOrbeonAppException signal: 'No application named [', app, '] was found'].
	latestVersionNumber := application getLastFormDefinitionVersionOf: form.
	orbeonDefinition := application definitionNamed: form.

	self requestContext response headerAt: 'orbeon-form-definition-version' put: latestVersionNumber printString.

	^((GRCodec forEncoding: 'utf-8') decode: orbeonDefinition xmlString) asString! !

!WAOrbeonPersistenceLayer methodsFor: 'service-get' stamp: 'BrunoBB 08/30/2015 17:26'!
getFormDefinitionWithId: id 
	"This service is called when a click is performed on the Orbeon Form Builder Summary page.
	The Summary then should open the Orbeon Builder with the code of the clicked form."
	| orbeonData |
	<get>
	<produces: 'application/xml'>
	<path: '/crud/orbeon/builder/data/{1}/data.xml'>

	^((GRCodec forEncoding: 'utf-8') 
		decode: (OrbeonApplication getSavedDefinitionWithId: id ifNone: [^NoOrbeonFormException signal]) xmlString) asString! !

!WAOrbeonPersistenceLayer methodsFor: 'other' stamp: 'BrunoBB 08/26/2015 17:16'!
getFormDescriptionFrom: xmlDocument ifNone: aBlock

	^(xmlDocument findElementNamed: 'description')
		ifNotNil: [:value | value strings isEmpty ifTrue: aBlock ifFalse: [value strings last]]
		ifNil: aBlock.! !

!WAOrbeonPersistenceLayer methodsFor: 'other' stamp: 'BrunoBB 08/26/2015 17:11'!
getFormNameFrom: xmlDocument ifNone: aBlock

	^(xmlDocument findElementNamed: 'form-name')
		ifNotNil: [:value | value strings isEmpty ifTrue: aBlock ifFalse: [value strings last]]
		ifNil: aBlock.! !

!WAOrbeonPersistenceLayer methodsFor: 'other' stamp: 'BrunoBB 09/04/2015 14:17'!
getFormTitleFrom: xmlDocument ifNone: aBlock

	^(xmlDocument findElementNamed: 'title')
		ifNotNil: [:value | value strings isEmpty ifTrue: aBlock ifFalse: [value strings last]]
		ifNil: aBlock.! !

!WAOrbeonPersistenceLayer methodsFor: 'service-get' stamp: 'BrunoBB 09/01/2015 13:16'!
getFormVersion: formName app: app 
	"This method is called by Orbeon when a Form Definition (inside the Builder) is about to be Published.
	This method answer the latest version of the form definition <formName> in application <app>.
	Using the header <orbeon-form-definition-version> to set the version number.
	It also called when a new Form Instance page is about to be displayed (app/form/new)"
	| application latestVersionNumber |
	<get>
	<produces: 'application/xml'>
	<path: '/crud/{2}/{1}/form/form.xhtml'>

	application := OrbeonApplication applicationNamed: app ifNone: [^NoOrbeonAppException signal: 'No application named [', app, '] was found'].
	latestVersionNumber := application getLastFormDefinitionVersionOf: formName.

	self requestContext response headerAt: 'orbeon-form-definition-version' put: latestVersionNumber printString.

	^((GRCodec forEncoding: 'utf-8') decode: (application getLatestSavedDefinition: formName) xmlString) asString! !

!WAOrbeonPersistenceLayer methodsFor: 'summary' stamp: 'BrunoBB 09/01/2015 15:26'!
getInstancesTypeFrom: xmlDocument for: username inGroup: group forForm: formName in: app
	| draftsNodes draftNode |

	draftsNodes := xmlDocument descendentElementsNamed: 'drafts'.
	draftsNodes isEmpty ifTrue: [^self getValidInstancesFor: username group: group inForm: formName in: app].

	draftNode := draftsNodes first.
	(((draftNode attributeAt: 'for-never-saved-document') = 'true') and: [draftNode contentString = 'only'])
	ifTrue: [^self getValidDraftsFor: username group: group inForm: formName in: app].

	^self getValidInstancesFor: username group: group inForm: formName in: app! !

!WAOrbeonPersistenceLayer methodsFor: 'service-get' stamp: 'BrunoBB 09/01/2015 17:46'!
getOrbeonFr
	"This service is called when accessing Form Runner Home: ../orbeon/fr/ "
	| xmlWriter |
	<get>
	<produces: 'application/xml'>
	<path: '/form'>

	xmlWriter := XMLWriter new.
	xmlWriter writeWith: [:writer | | tag | 
		writer tag: 'forms' with: [OrbeonApplication getLastDefinitions do: [:eachDef | 
			self getXmlNodeFor: eachDef with: writer]].
	].

	^xmlWriter contents! !

!WAOrbeonPersistenceLayer methodsFor: 'summary' stamp: 'BrunoBB 08/25/2015 16:01'!
getPageNumberFrom: xmlDocument
	| pageNumberNodes pageNumberNode |

	pageNumberNodes := xmlDocument allElementsNamed: 'page-number'.
	pageNumberNodes isEmpty ifTrue: [^1].

	pageNumberNode := pageNumberNodes last.
	pageNumberNode strings isEmpty ifTrue: [^1].

	^Number fromString: pageNumberNode strings last! !

!WAOrbeonPersistenceLayer methodsFor: 'summary' stamp: 'BrunoBB 08/25/2015 16:01'!
getPageSizeFrom: xmlDocument
	| pageSizeNodes pageSizeNode |

	pageSizeNodes := xmlDocument allElementsNamed: 'page-size'.
	pageSizeNodes isEmpty ifTrue: [^10].

	pageSizeNode := pageSizeNodes last.
	pageSizeNode strings isEmpty ifTrue: [^10].

	^Number fromString: pageSizeNode strings last! !

!WAOrbeonPersistenceLayer methodsFor: 'summary' stamp: 'BrunoBB 09/01/2015 13:56'!
getPermissionsFor: anOrbeonFormInstance user: username group: group in: formDefinition
	| printStream |

	printStream := PrintStream on: String new.

	((anOrbeonFormInstance hasUser: username createAccessUsing: formDefinition permissions) 
	or: [anOrbeonFormInstance hasRole: group createAccessUsing: formDefinition permissions])
		ifTrue: [printStream nextPutAll: 'create '].

	((anOrbeonFormInstance hasUser: username readAccessUsing: formDefinition permissions) 
	or: [anOrbeonFormInstance hasRole: group readAccessUsing: formDefinition permissions])
		ifTrue: [printStream nextPutAll: 'read '].

	((anOrbeonFormInstance hasUser: username updateAccessUsing: formDefinition permissions) 
	or: [anOrbeonFormInstance hasRole: group updateAccessUsing: formDefinition permissions])
		ifTrue: [printStream nextPutAll: 'update '].

	((anOrbeonFormInstance hasUser: username deleteAccessUsing: formDefinition permissions) 
	or: [anOrbeonFormInstance hasRole: group deleteAccessUsing: formDefinition permissions])
		ifTrue: [printStream nextPutAll: 'delete '].

	^printStream contents! !

!WAOrbeonPersistenceLayer methodsFor: 'summary' stamp: 'BrunoBB 08/25/2015 16:01'!
getQueryNodesFrom: xmlDocument
	"The receiver extract the -query nodes- from the XML Document <xmlDocument>.
	These -query nodes- are used to query the Orbeon Summary and to show summary fields"
	| queryNodes |

	queryNodes := OrderedCollection new.

	(xmlDocument allElementsNamed: 'query') do: [:node | | queryNode value |
		value := node strings notEmpty ifTrue: [node strings last] ifFalse: [nil].
		queryNode := OrbeonQueryNode new name: (node attributeAt: 'name');
								path: (node attributeAt: 'path');
								type: (node attributeAt: 'type');
								control: (node attributeAt: 'control');
								searchField: (node attributeAt: 'search-field'); 
								summaryField: (node attributeAt: 'summary-field'); 
								match: (node attributeAt: 'match'); 
								value: value;
								yourself.
		queryNodes add: queryNode.
		].

	^queryNodes! !

!WAOrbeonPersistenceLayer methodsFor: 'summary' stamp: 'BrunoBB 09/01/2015 14:55'!
getValidDraftsFor: username group: group inForm: formName in: app
	"Answer a collection of valid drafts for the form <formName> in application <app> for the current user <username> that belongs to the group <group>.
	For more details: https://github.com/orbeon/orbeon-forms/wiki/Form-Runner-~-Autosave"
	| application definition drafts |

	application := OrbeonApplication applicationNamed: app ifNone: [^NoOrbeonAppException signal: 'No such application [', app, ']'].
	definition := application definitionNamed: formName ifNone: [^NoOrbeonFormException signal: 'No such form [', formName, '] in application [', app,']'].

	drafts  := OrderedCollection new.

	definition drafts do: [:draftCollection |
		drafts addAll: (draftCollection select: [:each | each deleted = 'N' and: [(each hasUser: username readAccessUsing: definition permissions) or: [each hasRole: group readAccessUsing: definition permissions]]]).
	].

	^drafts! !

!WAOrbeonPersistenceLayer methodsFor: 'summary' stamp: 'BrunoBB 09/01/2015 15:25'!
getValidInstancesFor: username group: group inForm: formName in: app
	"Answer a collection of valid instances for the form <formName> in application <app> for the current user <username> that belongs to the group <group>"
	| application definition |

	application := OrbeonApplication applicationNamed: app ifNone: [^NoOrbeonAppException signal: 'No such application [', app, ']'].
	definition := application definitionNamed: formName ifNone: [^NoOrbeonFormException signal: 'No such form [', formName, '] in application [', app,']'].

	^(definition instances select: [:each | each deleted = 'N' and: [(each hasUser: username readAccessUsing: definition permissions) 
																	or: [each hasRole: group readAccessUsing: definition permissions]]]) asOrderedCollection
		addAll:
			(self getValidDraftsFor: username group: group inForm: formName in: app);
		yourself! !

!WAOrbeonPersistenceLayer methodsFor: 'summary' stamp: 'BrunoBB 09/03/2015 11:23'!
getXmlNodeFor: anOrbeonFormDefinition with: anXMLWriter

	anXMLWriter tag: 'form' with: [
		anXMLWriter tag: 'application-name' with: anOrbeonFormDefinition app.
		anXMLWriter tag: 'form-name' with: anOrbeonFormDefinition form.
		anXMLWriter tag: 'title' with: anOrbeonFormDefinition title.
		anXMLWriter tag: 'description' with: anOrbeonFormDefinition description.
		anXMLWriter tag: 'last-modified-time' with: anOrbeonFormDefinition modifiedTime asOrbeonDateTimeString.
		anXMLWriter tag: 'available' with: anOrbeonFormDefinition available.
	].! !

!WAOrbeonPersistenceLayer methodsFor: 'service-get' stamp: 'BrunoBB 09/01/2015 15:13'!
getXmlOfFormDraftWithId: id form: form app: app
	"This service is called when a click is performed on the Orbeon Form Summary page.
	The Summary then should open the Form Instance (view/edit mode ) in the corresponding form definition (template).
	This sevice is used in combination with #getDefinitionForFormInstanceWithId:form:app: that <get> the form definition (template) to the form with id <id>"
	| application definition instance permissions username group |
	<get>
	<produces: 'application/xml'>
	<path: '/crud/{3}/{2}/draft/{1}/data.xml'>

	application := OrbeonApplication applicationNamed: app ifNone: [^NoOrbeonAppException signal: 'No application named [', app, '] was found'].
	definition := OrbeonApplication formDefinitionNamed: form in: app.
	instance := definition getDraftWithId: id.

	group := self requestContext request headerAt: 'orbeon-group'.
	username := self requestContext request headerAt: 'orbeon-username'.
	permissions := self getPermissionsFor: instance user: username group: group in: definition.
	
	self requestContext response headerAt: 'orbeon-operations' put: permissions.

	^((GRCodec forEncoding: 'utf-8') decode: instance xmlString) asString! !

!WAOrbeonPersistenceLayer methodsFor: 'service-get' stamp: 'BrunoBB 09/01/2015 14:08'!
getXmlOfFormInstanceWithId: id form: form app: app
	"This service is called when a click is performed on the Orbeon Form Summary page.
	The Summary then should open the Form Instance (view/edit mode ) in the corresponding form definition (template).
	This sevice is used in combination with #getDefinitionForFormInstanceWithId:form:app: that <get> the form definition (template) to the form with id <id>"
	| application orbeonInstance definition permissions username group |
	<get>
	<produces: 'application/xml'>
	<path: '/crud/{3}/{2}/data/{1}/data.xml'>

	application := OrbeonApplication applicationNamed: app ifNone: [^NoOrbeonAppException signal: 'No application named [', app, '] was found'].
	definition := OrbeonApplication formDefinitionNamed: form in: app.
	orbeonInstance := definition getInstanceWithId: id.

	group := self requestContext request headerAt: 'orbeon-group'.
	username := self requestContext request headerAt: 'orbeon-username'.
	permissions := self getPermissionsFor: orbeonInstance user: username group: group in: definition.

	self requestContext response headerAt: 'orbeon-operations' put: permissions.

	^((GRCodec forEncoding: 'utf-8') decode: orbeonInstance xmlString) asString! !

!WAOrbeonPersistenceLayer methodsFor: 'other' stamp: 'BrunoBB 08/25/2015 16:02'!
hardCodeAnswer

	^'<documents xmlns:ev="http://www.w3.org/2001/xml-events" xmlns:f="http//www.orbeon.com/function" xmlns:frf="java:org.orbeon.oxf.fr.FormRunner" xmlns:odt="http://orbeon.org/oxf/xml/datatypes" xmlns:oxf="http://www.orbeon.com/oxf/processors" xmlns:p="http://www.orbeon.com/oxf/pipeline" xmlns:saxon="http://saxon.sf.net/" xmlns:sql="http://orbeon.org/oxf/xml/sql" xmlns:xf="http://www.w3.org/2002/xforms" xmlns:xi="http://www.w3.org/2001/XInclude" xmlns:xpl="java:org.orbeon.oxf.pipeline.api.FunctionLibrary" xmlns:xs="http://www.w3.org/2001/XMLSchema" xmlns:xxf="http://orbeon.org/oxf/xml/xforms" search-total="9" total="9">
	<document created="2015-07-15T22:11:24.849Z" draft="N" last-modified="2015-07-21T20:35:59.893Z" name="1526e81d6d405ec1ac1d4849f7cacfa18572220c" operations="*">
		<details>
			<detail>ue</detail>
			<detail>complete-test</detail>
			<detail>Complete Test</detail>
			<detail/>
		</details>
	</document>
	<document created="2015-06-13T23:44:05.993Z" draft="N" last-modified="2015-06-13T23:45:26.604Z" name="2e387e31fb83fb21d996708dc2c66c5e599ff4a1" operations="*">
		<details>
			<detail>ue</detail>
			<detail>procesar-permiso-general</detail>
			<detail>Procesar Permiso General</detail>
			<detail/>
		</details>
	</document>
	<document created="2015-06-13T23:41:57.945Z" draft="N" last-modified="2015-06-13T23:46:04.939Z" name="a233448a57a88e4d5d38fe8ad154832a82c96386" operations="*">
		<details>
			<detail>ue</detail>
			<detail>analisis-contruccion</detail>
			<detail>Analisis Construccion</detail>
			<detail/>
		</details>
	</document>
	<document created="2015-06-03T13:56:33.557Z" draft="N" last-modified="2015-06-03T19:01:44.747Z" name="bd1a4d6216254db2c2e46e6612b7c4b2eabaa726" operations="*">
		<details>
			<detail>ue</detail>
			<detail>resultado-permiso</detail>
			<detail>Resultado Permiso Construccion</detail>
			<detail/>
		</details>
	</document>
	<document created="2015-06-03T13:55:23.270Z" draft="N" last-modified="2015-06-03T19:00:57.204Z" name="6bfcdc725198640914adbb169b848c3651f182d9" operations="*">
		<details>
			<detail>ue</detail>
			<detail>analisis-estructura</detail>
			<detail>Analisis Estructura</detail>
			<detail/>
		</details>
	</document>
	<document created="2015-06-03T13:47:33.837Z" draft="N" last-modified="2015-06-03T19:00:17.169Z" name="8aaa73a2b8bfc710b4762e96597c62a2dbcfe7c0" operations="*">
		<details>
			<detail>ue</detail>
			<detail>procesar-permiso-fabrica</detail>
			<detail>Procesar Permiso FABRICA</detail>
			<detail/>
		</details>
	</document>
	<document created="2015-06-03T13:46:42.458Z" draft="N" last-modified="2015-06-03T18:59:40.262Z" name="bddc4e7171bfb0fe6d278f7694d2bb33e0e840a6" operations="*">
		<details>
			<detail>ue</detail>
			<detail>procesar-permiso-edificio</detail>
			<detail>Procesar Permiso Edificio</detail>
			<detail/>
		</details>
	</document>
	<document created="2015-06-03T13:45:45.653Z" draft="N" last-modified="2015-06-03T18:59:02.697Z" name="32f1b9377c2cc04d799aa5e3dd6b9c0ad6a68780" operations="*">
		<details>
			<detail>ue</detail>
			<detail>procesar-permiso-casa</detail>
			<detail>Procesar Permiso Casa</detail>
			<detail/>
		</details>
	</document>
	<document created="2015-06-03T13:44:39.982Z" draft="N" last-modified="2015-06-03T18:57:01.444Z" name="31c81f6274d68dce5f5e14e9efc163f32b2145dd" operations="*">
		<details>
			<detail>ue</detail>
			<detail>peticion-permiso-construccion</detail>
			<detail>Peticion Permiso Construccion</detail>
			<detail/>
		</details>
	</document>
</documents>'! !

!WAOrbeonPersistenceLayer methodsFor: 'other' stamp: 'BrunoBB 08/25/2015 16:02'!
hardCodeAnswer2

	^'<?xml version="1.0" encoding="UTF-8"?><forms><form>
        <application-name>orbeon</application-name>
        <form-name>w9</form-name>
        <title xml:lang="en">Request for Taxpayer Identification Number and Certification</title>
        <description xml:lang="en"/>
        <last-modified-time>2015-05-05T19:12:33.711-04:00</last-modified-time>
    </form><form>
        <application-name>orbeon</application-name>
        <form-name>library</form-name>
        <title xml:lang="en">Global Library</title>
        <description xml:lang="en">This special form contains the global Form Builder library of section templates accessible from all forms.</description>
        <title xml:lang="fr">Bibliothque globale</title>
        <description xml:lang="fr">Ce formulaire spcial contient la bibliothque global de Form Builder, avec les modles de sections disponibles depuis tous les formulaires.</description>
        <logo mediatype="" filename="" size=""/>
        <last-modified-time>2015-05-05T19:12:33.567-04:00</last-modified-time>
    </form><form>
        <application-name>orbeon</application-name>
        <form-name>controls</form-name>
        <title xml:lang="en">Form Builder Controls</title>
        <description xml:lang="en">This form shows all the built-in controls supported by Form Builder</description>
        <title xml:lang="fr">Contrles de Form Builder</title>
        <description xml:lang="fr">Ce formulaire montre tous les contrles supports par Form Builder</description>
        <last-modified-time>2015-05-05T19:12:33.178-04:00</last-modified-time>
    </form><form>
        <application-name>orbeon</application-name>
        <form-name>contact</form-name>
        <title xml:lang="en">Contact</title>
        <description xml:lang="en">The Contact form is a simple form which can be created in a few minutes with Form Builder.</description>
        <title xml:lang="fr">Contact</title>
        <description xml:lang="fr">Le formulaire Contact peut tre cr  laide de Form Builder en quelques minutes.</description>
        <last-modified-time>2015-05-05T19:12:33.011-04:00</last-modified-time>
    </form><form>
        <application-name>orbeon</application-name>
        <form-name>bookshelf</form-name>
        <title xml:lang="en">Orbeon Forms Bookshelf</title>
        <description xml:lang="en">Orbeon Forms Bookshelf is a simple form allowing you to gather information about books.</description>
        <title xml:lang="fr">Orbeon Forms Bookshelf</title>
        <description xml:lang="fr">Orbeon Forms Bookshelf prsente un formulaire simple qui vous permet de saisir des informations sur des livres.</description>
        <migration version="4.8.0">[{ "path": "notes/note", "iteration-name": "note-iteration" }]</migration>
        <last-modified-time>2015-05-05T19:12:29.311-04:00</last-modified-time>
    </form></forms>'! !

!WAOrbeonPersistenceLayer methodsFor: 'service-put' stamp: 'BrunoBB 08/30/2015 17:32'!
publishFormDefinition: formName app: app withId: documentId
	"This method is called by Orbeon when a Form Definition has been published with form name <formName> in application <app> with form id <documentId>"
	| orbeonApplication orbeonInstanceDefinition orbeonDefinition headerVersion currentVersion |
	<put>
	<consumes: 'application/xml'>
	<path: '/crud/{2}/{1}/form/form.xhtml?document={3}'>

	orbeonInstanceDefinition := OrbeonApplication getSavedDefinition: formName app: app withId: documentId.
	orbeonDefinition := orbeonInstanceDefinition definition.
	orbeonApplication := orbeonInstanceDefinition getApplication.

	headerVersion := (self requestContext request headerAt: 'orbeon-form-definition-version').
	currentVersion := orbeonApplication getLastFormDefinitionVersionOf: formName.
	"Orbeon put -next- when a new version is going to be generated if NOT --> the current version is updated"
	(headerVersion = 'next') ifTrue: [currentVersion := currentVersion + 1].

	orbeonDefinition 
		updateLastModifiedTime;
		version: currentVersion;
		xmlString: self requestContext request rawBody;
		publish;
		processXMLDefinition. "unimplemented: see: OrbeonApiConfiguration and OrbeonDeferredProcessing may this message should be sent later by other gem"

	orbeonApplication addPublishedDefinition: orbeonDefinition! !

!WAOrbeonPersistenceLayer methodsFor: 'service-put' stamp: 'BrunoBB 09/04/2015 12:52'!
receiveAndPublishFileFor: formName app: app documentId: documentId fileId: fileId
	"This service is called when a user click -Publish- form in Orbeon Form Builder and the form definition has attached files.
	The Form Definition is <formName> in the Orbeon Application <app> where the id of the form definition is <documentId> and the attached file id is <fileId>.
	This service is called for each attached files in the Form Definition. 
	The attached file is stored in the repository"
	| gsFile |
	<put>
	<path: '/crud/{2}/{1}/form/{4}?document={3}'>

	gsFile := GsFile open: ((self apiConfiguration getPublishedDefinitionsPathFor: formName in: app), fileId) mode: 'wb' onClient: false.

	gsFile
		nextPutAll: self requestContext request rawBody;
		flush;
		close.! !

!WAOrbeonPersistenceLayer methodsFor: 'service-put' stamp: 'BrunoBB 09/03/2015 15:02'!
receiveAndSaveFileForDefinitionWithId: definitionId fileId: fileId valid: aBoolean
	"This service receives a file with id <fileId> from Orbeon Form Builder when the a user clicked -Save-.
	The file was uploaded into a Form Definition as a Custom PDF or as direct file Upload.
	A direct file upload is when a File Attachment is added to a Form Definition and a concrete file is also uploaded"
	| definition stream gsFile |
	<put>
	<path: '/crud/orbeon/builder/data/{1}/{2}.bin?valid={3}'>

	definition := OrbeonApplication getAnyDefinitionWithId: definitionId ifNone: [^NoOrbeonFormException signal: 'No form definition with id [', definitionId, ']'].

	gsFile := GsFile open: ((self apiConfiguration getSavedDefinitionsPathFor: definition form in: definition app), fileId, '.bin') mode: 'wb' onClient: false.

	gsFile
		nextPutAll: self requestContext request rawBody;
		flush;
		close.! !

!WAOrbeonPersistenceLayer methodsFor: 'service-put' stamp: 'BrunoBB 09/03/2015 15:00'!
receiveAndSaveFileForDraft: formName app: app definitionId: definitionId fileId: fileId valid: aBoolean
	"This service is called from Orbeon Form Runner -new/edit- when a file is uploaded (and autosave is -true-) to a Form Instance.
	When the form is autosaved then all form's attachments are sent to this service "
	| stream gsFile |
	<put>
	<path: '/crud/{2}/{1}/draft/{3}/{4}?valid={5}'>

	gsFile := GsFile open: ((self apiConfiguration getDraftsPathFor: formName in: app), fileId) mode: 'wb' onClient: false.

	gsFile
		nextPutAll: self requestContext request rawBody;
		flush;
		close.! !

!WAOrbeonPersistenceLayer methodsFor: 'service-put' stamp: 'BrunoBB 09/03/2015 15:00'!
receiveAndSaveFileForInstance: formName app: app definitionId: definitionId fileId: fileId valid: aBoolean
	"This service is called from Orbeon Form Runner -new/edit- when a file is uploaded to a Form Instance.
	When the form is sent then all form's attachments are sent to this service"
	| stream gsFile |
	<put>
	<path: '/crud/{2}/{1}/data/{3}/{4}?valid={5}'>

	gsFile := GsFile open: ((self apiConfiguration getInstancesPathFor: formName in: app), fileId) mode: 'wb' onClient: false.

	gsFile
		nextPutAll: self requestContext request rawBody;
		flush;
		close.! !

!WAOrbeonPersistenceLayer methodsFor: 'service-put' stamp: 'BrunoBB 09/01/2015 15:17'!
saveDraftFormInstance: formName app: app withId: id valid: aBoolean
	"This method is called by Orbeon when a Form is autosaved in a Form Instance page"
	| application definition orbeonDraft |
	<put>
	<produces: 'application/xml'>
	<path: '/crud/{2}/{1}/draft/{3}/data.xml?valid={4}'>

	application := OrbeonApplication applicationNamed: app ifNone: [^NoOrbeonAppException signal: 'No such application [', app, ']'].
	definition := application definitionNamed: formName ifNone: [^NoOrbeonFormException signal: 'No such form [', formName, '] in application [', app, ']'].
	orbeonDraft := OrbeonFormInstance app: app form: formName id: id. "we preserve the existing form instance so we create a new one"

	orbeonDraft xmlString: self requestContext request rawBody;
		definition: definition;
		draft: 'Y';
		version: (self requestContext request headerAt: 'orbeon-form-definition-version');
		username:  (self requestContext request headerAt: 'orbeon-username'); "BUG - creator set only one time"
		modifiedUser: (self requestContext request headerAt: 'orbeon-username');
		groupname: (self requestContext request headerAt: 'orbeon-group');
		updateLastModifiedTime.

	definition addDraft: orbeonDraft.! !

!WAOrbeonPersistenceLayer methodsFor: 'service-put' stamp: 'BrunoBB 09/01/2015 15:17'!
saveFinalFormInstance: formName app: app withId: id valid: aBoolean
	"This method is called by Orbeon when a user click 'Send' in a Form Instance page"
	| application definition instance |
	<put>
	<produces: 'application/xml'>
	<path: '/crud/{2}/{1}/data/{3}/data.xml?valid={4}'>

	application := OrbeonApplication applicationNamed: app ifNone: [^NoOrbeonAppException signal: 'No such application [', app, ']'].
	definition := application definitionNamed: formName ifNone: [^NoOrbeonFormException signal: 'No such form [', formName, '] in application [', app, ']'].
	instance := definition getInstanceWithId: id ifNone: [OrbeonFormInstance app: app form: formName id: id].

	instance xmlString: self requestContext request rawBody;
		definition: definition;
		version: (self requestContext request headerAt: 'orbeon-form-definition-version');
		username:  (self requestContext request headerAt: 'orbeon-username'); "BUG - creator set only one time"
		modifiedUser: (self requestContext request headerAt: 'orbeon-username');
		groupname: (self requestContext request headerAt: 'orbeon-group');
		isValid: aBoolean;
		updateLastModifiedTime.

	"(OrbeonApiConfiguration default processingIsDeferredFor: formName in: app) ifTrue: [] ifFalse: [instance processXML]."

	instance processXML.
	definition removeDraft: instance. "this is the final version so we remove the current draft"! !

!WAOrbeonPersistenceLayer methodsFor: 'service-put' stamp: 'BrunoBB 09/04/2015 14:15'!
saveInFormBuilderDefinitionWithId: id valid: aBoolean
	"This service is called by Orbeon when a user click on -Save- inside the Form Builder.
	A Form Definition has been saved "
	| orbeonData xml xmlDocument orbeonApplication savedDefinition appName formName |
	<put>
	<path: '/crud/orbeon/builder/data/{1}/data.xml/?valid={2}'>

	xml := self requestContext request rawBody.
	xmlDocument := XMLDOMParser parse: xml.
	appName := self getApplicationNameFrom: xmlDocument ifNone: [nil].
	formName := self getFormNameFrom: xmlDocument ifNone: [nil].
	orbeonApplication := OrbeonApplication applicationNamed: appName ifNone: [self createOrbeonApplicationNamed: appName].
	savedDefinition := orbeonApplication getSavedDefinitionFor: formName withId: id 
														ifNone: [OrbeonFormInstanceDefinition new app: appName; form: formName; yourself].
	savedDefinition id: id;
		version: (self requestContext request headerAt: 'orbeon-form-definition-version');
		title: (self getFormTitleFrom: xmlDocument ifNone: ['']);
		description: (self getFormDescriptionFrom: xmlDocument ifNone: ['']);
		setXmlString: xml;
		updateLastModifiedTime;
		processXMLDefinition; "unimplemented: see: OrbeonApiConfiguration and OrbeonDeferredProcessing may this message should be sent later by other gem"
		yourself.
	orbeonApplication addSavedDefinition: savedDefinition.! !

!WAOrbeonPersistenceLayer methodsFor: 'service-post' stamp: 'BrunoBB 08/30/2015 16:27'!
searchInFormBuilderSummary
	"This service is called by Orbeon when rendering an Orbeon Form Builder Summary page and
	answer a well formatted XML with the result of the query received in the request.
	This XML is going to be displayed in the Orbeon Form Builder Summary page"	
	| xmlDocument definitions pageSize pageNumber from to |
	<post>
	<produces: 'application/xml'>
	<path: '/search/orbeon/builder'>

	xmlDocument := XMLDOMParser parse: self requestContext request rawBody.
	definitions := self applyQueryToFormDefinition: xmlDocument.
	pageSize := self getPageSizeFrom: xmlDocument.
	pageNumber := self getPageNumberFrom: xmlDocument.
	to := pageSize * pageNumber.
	from := to - pageSize + 1.
	to := (to>= definitions size) ifTrue: [definitions size] ifFalse: [to].

	^self generateXmlAnswerForBuilderSummary: (definitions copyFrom: from to: to)
			searchTotal: definitions size! !

!WAOrbeonPersistenceLayer methodsFor: 'service-post' stamp: 'BrunoBB 09/01/2015 13:39'!
searchInFormSummary: formName app: app
	"This service is called by Orbeon when rendering an Orbeon Form Summary page and
	answer a well formatted XML with the result of the query received in the request.
	This XML is going to be displayed in the Orbeon Form Summary page"
	| application definition xmlDocument queryNodes instances group username filteredInstances pageSize pageNumber from to |
	<post>
	<produces: 'application/xml'>
	<path: '/search/{2}/{1}'>

	application := OrbeonApplication applicationNamed: app ifNone: [^NoOrbeonAppException signal: 'No such application [', app, ']'].
	definition := application definitionNamed: formName ifNone: [^NoOrbeonFormException signal: 'No such form [', formName, '] in application [', app,']'].
	xmlDocument := XMLDOMParser parse: self requestContext request rawBody.
	queryNodes := self getQueryNodesFrom: xmlDocument.
	group := self requestContext request headerAt: 'orbeon-group'.
	username := self requestContext request headerAt: 'orbeon-username'.
	instances := self getInstancesTypeFrom: xmlDocument for: username inGroup: group forForm: formName in: app.
	"here apply the filters for that entered in the web application for search purpose (example: id=123456)"

	filteredInstances := self applyQueryToFormInstance: instances queryNodes: queryNodes.

	pageSize := self getPageSizeFrom: xmlDocument.
	pageNumber := self getPageNumberFrom: xmlDocument.
	to := pageSize * pageNumber.
	from := to - pageSize + 1.
	to := (to>= filteredInstances size) ifTrue: [filteredInstances size] ifFalse: [to].

	^self generateXmlAnswerFor: definition
				summary: (filteredInstances copyFrom: from to: to)
				withQueryNodes: queryNodes
				user: username
				group: group
				searchTotal: filteredInstances size! !

!WAOrbeonPersistenceLayer methodsFor: 'other' stamp: 'BrunoBB 08/25/2015 16:02'!
seasideMimeDocument

	^WAMimeDocument on: 'OK' mimeType: WAMimeType textPlain! !

!WAOrbeonPersistenceLayer methodsFor: 'service-get' stamp: 'BrunoBB 09/03/2015 14:58'!
sendFileForDefinitionWithId: definitionId fileId: fileId
	"This service is called by Orbeon Form Builder to get/obtain the attached file with id <fileId> for the Form Definition <definitionId>.
	The service answer an octet stream to the caller."
	| definition contents gsFile |
	<get>
	<produces: 'application/octet-stream'>
	<path: '/crud/orbeon/builder/data/{1}/{2}'>

	definition := OrbeonApplication getAnyDefinitionWithId: definitionId ifNone: [^NoOrbeonFormException signal: 'No form definition with id [', definitionId, ']'].

	self requestContext response contentType: WAMimeType applicationOctetStream.

	gsFile := GsFile openOnServer: ((self apiConfiguration getSavedDefinitionsPathFor: definition form in: definition app), fileId) mode: 'rb'.
	contents := gsFile contentsAsUtf8.

	gsFile close.

	^contents! !

!WAOrbeonPersistenceLayer methodsFor: 'service-get' stamp: 'BrunoBB 09/03/2015 14:46'!
sendFileForDraft: formName app: app definitionId: definitionId fileId: fileId
	"This service is called when rendering the Draft of the form in Form Instance page"
	| contents gsFile |
	<get>
	<produces: 'application/octet-stream'>
	<path: '/crud/{2}/{1}/draft/{3}/{4}'>

	self requestContext response contentType: WAMimeType applicationOctetStream.

	gsFile := GsFile openOnServer: ((self apiConfiguration getDraftsPathFor: formName in: app), fileId) mode: 'rb'.
	contents := gsFile contentsAsUtf8.

	gsFile close.

	^contents! !

!WAOrbeonPersistenceLayer methodsFor: 'service-get' stamp: 'BrunoBB 09/03/2015 14:47'!
sendFileForInstance: formName app: app definitionId: definitionId fileId: fileId
	"This service is called when rendering the form Instance in Form Instance page"
	| contents gsFile |
	<get>
	<produces: 'application/octet-stream'>
	<path: '/crud/{2}/{1}/data/{3}/{4}'>

	self requestContext response contentType: WAMimeType applicationOctetStream.

	gsFile := GsFile openOnServer: ((self apiConfiguration getInstancesPathFor: formName in: app), fileId) mode: 'rb'.
	contents := gsFile contentsAsUtf8.

	gsFile close.

	^contents! !

!WAOrbeonPersistenceLayer methodsFor: 'service-get' stamp: 'BrunoBB 09/03/2015 14:48'!
sendFileForInstance: formName app: app fileId: fileId
	"This service is called when Orbeon requires a Custom PDF of a form or the Form Instance has any attachments and the user has clicked -Send-"
	| contents gsFile |
	<get>
	<produces: 'application/octet-stream'>
	<path: '/crud/{2}/{1}/form/{3}'>

	self requestContext response contentType: WAMimeType applicationOctetStream.

	gsFile := GsFile openOnServer: ((self apiConfiguration getPublishedDefinitionsPathFor: formName in: app), fileId) mode: 'rb'.
	contents := gsFile contentsAsUtf8.

	gsFile close.

	^contents! !

!WAOrbeonPersistenceLayer methodsFor: 'service-put' stamp: 'BrunoBB 09/03/2015 11:59'!
unpublishFormDefinition: formName app: app
	"This method is called by Orbeon when a Form Definition has been unpublished with form name <formName> in application <app>"
	| application definition |
	<put>
	<path: '/crud/{2}/{1}/form/form.xhtml'>

	application := OrbeonApplication applicationNamed: app ifNone: [^NoOrbeonAppException signal: 'No such application [', app, ']'].
	definition := application definitionNamed: formName ifNone: [^NoOrbeonFormException signal: 'No such form [', formName, '] in application [', app, ']'].

	definition switchAvailable! !

Object subclass: #OrbeonApiConfiguration
	instanceVariableNames: 'isEnabled deferredXmlProcessing bpmForms pathForAttachments baseAttachmentPath'
	classVariableNames: 'Default'
	poolDictionaries: ''
	category: 'Orbeon_Persistence_API'!

!OrbeonApiConfiguration class methodsFor: 'other' stamp: 'BrunoBB 09/01/2015 12:34'!
default

	Default ifNil: [Default := super new initialize].

	^Default! !

!OrbeonApiConfiguration class methodsFor: 'other' stamp: 'BrunoBB 09/03/2015 12:57'!
initialize

	super initialize.

	Default := super new initialize! !

!OrbeonApiConfiguration methodsFor: 'Accessing' stamp: 'BrunoBB 09/03/2015 14:30'!
baseAttachmentPath
	^baseAttachmentPath! !

!OrbeonApiConfiguration methodsFor: 'Updating' stamp: 'BrunoBB 09/03/2015 14:30'!
baseAttachmentPath: newValue
	baseAttachmentPath := newValue! !

!OrbeonApiConfiguration methodsFor: 'Accessing' stamp: 'BrunoBB 09/03/2015 12:51'!
bpmForms
	^bpmForms! !

!OrbeonApiConfiguration methodsFor: 'Updating' stamp: 'BrunoBB 09/03/2015 12:51'!
bpmForms: newValue
	bpmForms := newValue! !

!OrbeonApiConfiguration methodsFor: 'Accessing' stamp: 'BrunoBB 08/26/2015 17:48'!
deferredXmlProcessing
	^deferredXmlProcessing! !

!OrbeonApiConfiguration methodsFor: 'Updating' stamp: 'BrunoBB 08/26/2015 17:48'!
deferredXmlProcessing: newValue
	deferredXmlProcessing := newValue! !

!OrbeonApiConfiguration methodsFor: 'other' stamp: 'BrunoBB 09/03/2015 14:31'!
getBasePathFor: formName in: appName
	"The receiver answer the base path where attachment of form <formName> in application <appName> are stored"

	^(pathForAttachments at: appName ifAbsent: [^baseAttachmentPath])
		at: formName ifAbsent: [baseAttachmentPath]! !

!OrbeonApiConfiguration methodsFor: 'other' stamp: 'BrunoBB 09/03/2015 14:35'!
getDraftsPathFor: formName in: appName
	"The receiver answer the base path where attachment of form <formName> in application <appName> are stored"


	^(self getBasePathFor: formName in: appName), 'drafts/'! !

!OrbeonApiConfiguration methodsFor: 'other' stamp: 'BrunoBB 09/03/2015 14:35'!
getInstancesPathFor: formName in: appName
	"The receiver answer the base path where attachment of form <formName> in application <appName> are stored"


	^(self getBasePathFor: formName in: appName), 'instances/'! !

!OrbeonApiConfiguration methodsFor: 'other' stamp: 'BrunoBB 09/03/2015 14:36'!
getPublishedDefinitionsPathFor: formName in: appName
	"The receiver answer the base path where attachment of form <formName> in application <appName> are stored"


	^(self getBasePathFor: formName in: appName), 'definitions/published/'! !

!OrbeonApiConfiguration methodsFor: 'other' stamp: 'BrunoBB 09/03/2015 14:34'!
getSavedDefinitionsPathFor: formName in: appName
	"The receiver answer the base path where attachment of form <formName> in application <appName> are stored"


	^(self getBasePathFor: formName in: appName), 'definitions/saved/'! !

!OrbeonApiConfiguration methodsFor: 'other' stamp: 'BrunoBB 09/03/2015 14:30'!
initialize

	super initialize.

	baseAttachmentPath := '/opt/orbeon-files/'.
	isEnabled := false.
	"some forms can be processed on demand others later. If <true> is deferred processing if <false> is on demand"
	deferredXmlProcessing := Dictionary new. 
	bpmForms := Dictionary new. "some forms are used in the BPM application others not (only as regular Orbeon Forms) "
	pathForAttachments := Dictionary new. "the path to store attachments of the forms"! !

!OrbeonApiConfiguration methodsFor: 'other' stamp: 'BrunoBB 09/03/2015 13:34'!
isDeferredProcessing: formName in: appName
	"Answer whether of not the form named <formName> in the application <appName> has deferred XML processing
	If value is <true> then the XML processing is deferred"

	^(deferredXmlProcessing at: appName ifAbsent: [^false])
		at: formName! !

!OrbeonApiConfiguration methodsFor: 'Accessing' stamp: 'BrunoBB 08/26/2015 17:49'!
isEnabled
	^isEnabled! !

!OrbeonApiConfiguration methodsFor: 'Updating' stamp: 'BrunoBB 08/26/2015 17:49'!
isEnabled: newValue
	isEnabled := newValue! !

!OrbeonApiConfiguration methodsFor: 'other' stamp: 'BrunoBB 09/03/2015 13:35'!
isOnDemandProcessing: formName in: appName
	"Answer whether of not the form named <formName> in the application <appName> has on demand XML processing
	If value is <false> then the XML processing is on demand"

	^((deferredXmlProcessing at: appName ifAbsent: [^true])
		at: formName) not! !

!OrbeonApiConfiguration methodsFor: 'Accessing' stamp: 'BrunoBB 09/03/2015 12:54'!
pathForAttachments
	^pathForAttachments! !

!OrbeonApiConfiguration methodsFor: 'Updating' stamp: 'BrunoBB 09/03/2015 12:54'!
pathForAttachments: newValue
	pathForAttachments := newValue! !

!OrbeonApiConfiguration methodsFor: 'other' stamp: 'BrunoBB 09/03/2015 13:36'!
setDeferredProcessingFor: formName in: appName
	"The receiver set the XML processing as -Deferred- for the form named <formName> in the applicacion named <appName> "

	^(deferredXmlProcessing at: appName ifAbsentPut: [Dictionary new])
		at: formName put: true! !

!OrbeonApiConfiguration methodsFor: 'other' stamp: 'BrunoBB 09/03/2015 13:36'!
setOnDemandProcessingFor: formName in: appName
	"The receiver set the XML processing as -On Demand- for the form named <formName> in the applicacion named <appName> "

	^(deferredXmlProcessing at: appName ifAbsentPut: [Dictionary new])
		at: formName put: false! !

!OrbeonApiConfiguration methodsFor: 'other' stamp: 'BrunoBB 09/03/2015 13:58'!
setPath: aPath for: formName in: appName
	"The receiver set the path <aPath> to store forms attachment for form named <formName> in the application <appName> "

	^(pathForAttachments at: appName ifAbsentPut: [Dictionary new])
		at: formName put: aPath! !

Object subclass: #OrbeonDeferredProcessingQueue
	instanceVariableNames: 'instances savedDefinitions definitions'
	classVariableNames: 'Default'
	poolDictionaries: ''
	category: 'Orbeon_Persistence_API'!

!OrbeonDeferredProcessingQueue methodsFor: 'Accessing' stamp: 'BrunoBB 09/01/2015 12:33'!
definitions
	^definitions! !

!OrbeonDeferredProcessingQueue methodsFor: 'Updating' stamp: 'BrunoBB 09/01/2015 12:33'!
definitions: newValue
	definitions := newValue! !

!OrbeonDeferredProcessingQueue methodsFor: 'other' stamp: 'BrunoBB 09/01/2015 12:33'!
initialize

	super initialize.

	definitions := RcIdentityBag new.
	instances := RcIdentityBag new.
	savedDefinitions := RcIdentityBag new.! !

!OrbeonDeferredProcessingQueue methodsFor: 'Accessing' stamp: 'BrunoBB 09/01/2015 12:33'!
instances
	^instances! !

!OrbeonDeferredProcessingQueue methodsFor: 'Updating' stamp: 'BrunoBB 09/01/2015 12:33'!
instances: newValue
	instances := newValue! !

!OrbeonDeferredProcessingQueue methodsFor: 'Accessing' stamp: 'BrunoBB 09/01/2015 12:33'!
savedDefinitions
	^savedDefinitions! !

!OrbeonDeferredProcessingQueue methodsFor: 'Updating' stamp: 'BrunoBB 09/01/2015 12:33'!
savedDefinitions: newValue
	savedDefinitions := newValue! !

Object subclass: #OrbeonMaintenanceScript
	instanceVariableNames: ''
	classVariableNames: ''
	poolDictionaries: ''
	category: 'Orbeon_Persistence_API'!

!OrbeonMaintenanceScript class methodsFor: 'other' stamp: 'BrunoBB 09/05/2015 09:06'!
deleteUnusedOSFiles
	"The receiver delete all unused files from OS file system"
	| allAttachmentIds |

	allAttachmentIds := OrderedCollection new.

	OrbeonApplication cache do: [:eachApp | 
		eachApp definitionRegistry keysAndValuesDo: [:formName :registry |

			registry currentVersions do: [:eachDef | 
				allAttachmentIds addAll: eachDef attachments.
				(eachDef instances do: [:eachInst | allAttachmentIds addAll: eachInst getAttachmentIds])].

			registry oldVersions do: [:eachDef | allAttachmentIds addAll: eachDef attachments].

			registry savedDefinitions do: [:eachInstDef | eachInstDef].

		].
	].

	^allAttachmentIds! !
OrbeonApiConfiguration initialize!
